United States
New cases: 18263
New cases: 18611
New cases: 19056
New cases: 20634
New cases: 21675
New cases: 23790
New cases: 25294
New cases: 23285
New cases: 20260
New cases: 21551
New cases: 18937
New cases: 24996
New cases: 25050
New cases: 27368
New cases: 21030
New cases: 21495
New cases: 18621
New cases: 19710
New cases: 25621
New cases: 26906
New cases: 27692
1,699,781
100,439
New York
New cases: 1129
New cases: 1072
New cases: 1249
New cases: 1589
New cases: 1772
New cases: 1696
New cases: 2088
New cases: 1525
New cases: 1474
New cases: 1250
New cases: 1889
New cases: 2419
New cases: 2762
New cases: 2390
New cases: 2176
New cases: 1430
New cases: 1660
New cases: 2273
New cases: 2715
New cases: 2938
New cases: 3491
364,965
29,484
New Jersey
New cases: 864
New cases: 672
New cases: 938
New cases: 1014
New cases: 561
New cases: 993
New cases: 810
New cases: 1420
New cases: 1116
New cases: 1736
New cases: 1415
New cases: 1105
New cases: 1280
New cases: 1144
New cases: 643
New cases: 711
New cases: 1452
New cases: 1357
New cases: 1557
New cases: 1849
New cases: 2101
156,628
11,339
Illinois
New cases: 1111
New cases: 1178
New cases: 1713
New cases: 2508
New cases: 2352
New cases: 2756
New cases: 2270
New cases: 2388
New cases: 1545
New cases: 2294
New cases: 1734
New cases: 2088
New cases: 2432
New cases: 3243
New cases: 1673
New cases: 4014
New cases: 1266
New cases: 1656
New cases: 2325
New cases: 2889
New cases: 2639
114,306
5,083
California
New cases: 1663
New cases: 2987
New cases: 2380
New cases: 1481
New cases: 2287
New cases: 2221
New cases: 2034
New cases: 2245
New cases: 2295
New cases: 1291
New cases: 1441
New cases: 2032
New cases: 1822
New cases: 2073
New cases: 1820
New cases: 1649
New cases: 1729
New cases: 1042
New cases: 2779
New cases: 1631
New cases: 1532
101,807
3,919
Massachusetts
New cases: 527
New cases: 422
New cases: 596
New cases: 1013
New cases: 773
New cases: 805
New cases: 1114
New cases: 1045
New cases: 873
New cases: 1042
New cases: 1077
New cases: 1512
New cases: 1239
New cases: 1685
New cases: 1165
New cases: 870
New cases: 669
New cases: 1050
New cases: 1410
New cases: 1612
New cases: 1696
94,220
6,547
Pennsylvania
New cases: 779
New cases: 853
New cases: 362
New cases: 554
New cases: 798
New cases: 959
New cases: 1126
New cases: 815
New cases: 642
New cases: 969
New cases: 515
New cases: 1049
New cases: 1031
New cases: 1004
New cases: 791
New cases: 851
New cases: 520
New cases: 1379
New cases: 1189
New cases: 1415
New cases: 1156
73,557
5,265
Texas
New cases: 1312
New cases: 821
New cases: 548
New cases: 1085
New cases: 1237
New cases: 486
New cases: 1380
New cases: 1121
New cases: 1375
New cases: 781
New cases: 944
New cases: 1731
New cases: 1241
New cases: 1460
New cases: 1588
New cases: 877
New cases: 1297
New cases: 864
New cases: 1148
New cases: 1210
New cases: 1108
58,542
1,581
Michigan
New cases: 504
New cases: 223
New cases: 202
New cases: 314
New cases: 452
New cases: 403
New cases: 501
New cases: 659
New cases: 435
New cases: 773
New cases: 604
New cases: 459
New cases: 497
New cases: 1191
New cases: 370
New cases: 469
New cases: 370
New cases: 367
New cases: 429
New cases: 641
New cases: 566
55,608
5,334
Florida
New cases: 379
New cases: 509
New cases: 879
New cases: 740
New cases: 676
New cases: 776
New cases: 1204
New cases: 527
New cases: 502
New cases: 854
New cases: 777
New cases: 673
New cases: 928
New cases: 808
New cases: 479
New cases: 941
New cases: 386
New cases: 595
New cases: 802
New cases: 371
New cases: 826
52,634
2,319
Maryland
New cases: 736
New cases: 535
New cases: 839
New cases: 818
New cases: 1071
New cases: 893
New cases: 1208
New cases: 777
New cases: 1784
New cases: 958
New cases: 836
New cases: 982
New cases: 1083
New cases: 1091
New cases: 751
New cases: 688
New cases: 786
New cases: 1053
New cases: 1049
New cases: 1111
New cases: 1211
48,423
2,392
Georgia
New cases: 655
New cases: 583
New cases: 498
New cases: 660
New cases: 760
New cases: 819
New cases: 862
New cases: 946
New cases: 572
New cases: 704
New cases: 367
New cases: 440
New cases: 795
New cases: 550
New cases: 503
New cases: 922
New cases: 422
New cases: 992
New cases: 407
New cases: 563
New cases: 875
44,638
1,933
Connecticut
New cases: -15
New cases: 430
New cases: 405
New cases: 446
New cases: 382
New cases: 432
New cases: 191
New cases: 587
New cases: 314
New cases: 697
New cases: 716
New cases: 618
New cases: 621
New cases: 609
New cases: 522
New cases: 568
New cases: 211
New cases: 570
New cases: 573
New cases: 627
New cases: 789
41,288
3,803
Virginia
New cases: 907
New cases: 1615
New cases: 1483
New cases: 495
New cases: 799
New cases: 813
New cases: 1229
New cases: 763
New cases: 1005
New cases: 752
New cases: 705
New cases: 1011
New cases: 859
New cases: 1067
New cases: 946
New cases: 730
New cases: 989
New cases: 885
New cases: 854
New cases: 772
New cases: 585
40,249
1,281
Louisiana
New cases: 443
New cases: 245
New cases: 640
New cases: 244
New cases: 0
New cases: 421
New cases: 1188
New cases: 278
New cases: 329
New cases: 277
New cases: 315
New cases: 280
New cases: 348
New cases: 827
New cases: 612
New cases: 235
New cases: 215
New cases: 183
New cases: 562
New cases: 203
New cases: 253
38,497
2,723
Ohio
New cases: 433
New cases: 529
New cases: 566
New cases: 503
New cases: 614
New cases: 627
New cases: 731
New cases: 484
New cases: 498
New cases: 531
New cases: 449
New cases: 520
New cases: 597
New cases: 636
New cases: 471
New cases: 473
New cases: 696
New cases: 384
New cases: 681
New cases: 885
New cases: 555
33,439
2,044
Indiana
New cases: 359
New cases: 363
New cases: 339
New cases: 475
New cases: 492
New cases: 473
New cases: 662
New cases: 569
New cases: 450
New cases: 477
New cases: 498
New cases: 624
New cases: 603
New cases: 580
New cases: 346
New cases: 500
New cases: 501
New cases: 394
New cases: 586
New cases: 643
New cases: 633
32,437
2,030
North Carolina
New cases: 461
New cases: 398
New cases: 692
New cases: 501
New cases: 754
New cases: 1598
New cases: 250
New cases: 1023
New cases: 32
New cases: 534
New cases: 543
New cases: 636
New cases: 526
New cases: 616
New cases: 730
New cases: 348
New cases: 336
New cases: 460
New cases: 472
New cases: 466
New cases: 487
24,916
844
Colorado
New cases: 202
New cases: 296
New cases: 82
New cases: 210
New cases: 477
New cases: 296
New cases: 394
New cases: 315
New cases: 280
New cases: 264
New cases: 305
New cases: 401
New cases: 394
New cases: 363
New cases: 318
New cases: 278
New cases: 176
New cases: 328
New cases: 548
New cases: 457
New cases: 538
24,754
1,392
Minnesota
New cases: 504
New cases: 645
New cases: 742
New cases: 728
New cases: 840
New cases: 805
New cases: 530
New cases: 641
New cases: 657
New cases: 704
New cases: 699
New cases: 729
New cases: 805
New cases: 518
New cases: 423
New cases: 695
New cases: 528
New cases: 481
New cases: 702
New cases: 723
New cases: 786
22,464
942
Tennessee
New cases: 390
New cases: 360
New cases: 424
New cases: 326
New cases: 391
New cases: 433
New cases: 549
New cases: 0
New cases: 401
New cases: 652
New cases: 96
New cases: 303
New cases: 261
New cases: 329
New cases: 259
New cases: 567
New cases: 559
New cases: 217
New cases: 327
New cases: 345
New cases: 158
21,285
353
Washington
New cases: 225
New cases: 116
New cases: 237
New cases: 563
New cases: 0
New cases: 148
New cases: 146
New cases: 160
New cases: 200
New cases: 178
New cases: 145
New cases: 337
New cases: 178
New cases: 261
New cases: 182
New cases: 208
New cases: 231
New cases: 217
New cases: 286
New cases: 157
New cases: 326
20,406
1,095
Iowa
New cases: 666
New cases: 146
New cases: 306
New cases: 353
New cases: 406
New cases: 322
New cases: 550
New cases: 324
New cases: 341
New cases: 304
New cases: 323
New cases: 279
New cases: 374
New cases: 386
New cases: 377
New cases: 539
New cases: 414
New cases: 288
New cases: 214
New cases: 398
New cases: 655
18,369
496
Arizona
New cases: 454
New cases: 289
New cases: 198
New cases: 324
New cases: 429
New cases: 276
New cases: 442
New cases: 330
New cases: 368
New cases: 263
New cases: 279
New cases: 497
New cases: 495
New cases: 458
New cases: 480
New cases: 353
New cases: 264
New cases: 159
New cases: 434
New cases: 581
New cases: 238
17,318
834
Wisconsin
New cases: 599
New cases: 279
New cases: 307
New cases: 400
New cases: 481
New cases: 511
New cases: 472
New cases: 528
New cases: 198
New cases: 144
New cases: 356
New cases: 502
New cases: 410
New cases: 373
New cases: 291
New cases: 193
New cases: 199
New cases: 280
New cases: 349
New cases: 375
New cases: 314
16,462
539
Alabama
New cases: 382
New cases: 664
New cases: 508
New cases: 361
New cases: 447
New cases: 382
New cases: 236
New cases: 676
New cases: 290
New cases: 315
New cases: 97
New cases: 301
New cases: 272
New cases: 401
New cases: 236
New cases: 300
New cases: 275
New cases: 221
New cases: 283
New cases: 339
New cases: 355
16,032
583
Rhode Island
New cases: 143
New cases: 145
New cases: 0
New cases: 113
New cases: 216
New cases: 165
New cases: 215
New cases: 405
New cases: 156
New cases: 121
New cases: 240
New cases: 215
New cases: 203
New cases: 181
New cases: 221
New cases: 164
New cases: 176
New cases: 285
New cases: 210
New cases: 249
New cases: 325
14,353
655
Mississippi
New cases: 313
New cases: 273
New cases: 198
New cases: 255
New cases: 380
New cases: 403
New cases: 255
New cases: 263
New cases: 272
New cases: 136
New cases: 173
New cases: 322
New cases: 318
New cases: 393
New cases: 182
New cases: 234
New cases: 173
New cases: 123
New cases: 288
New cases: 404
New cases: 262
14,044
670
Nebraska
New cases: 365
New cases: 257
New cases: 228
New cases: 171
New cases: 301
New cases: 235
New cases: 305
New cases: 268
New cases: 229
New cases: 448
New cases: -43
New cases: 610
New cases: 350
New cases: 348
New cases: 380
New cases: 125
New cases: 236
New cases: 78
New cases: 275
New cases: 484
New cases: 645
12,984
153
Missouri
New cases: 237
New cases: 103
New cases: 327
New cases: 183
New cases: 130
New cases: 147
New cases: 161
New cases: 135
New cases: 151
New cases: 134
New cases: 149
New cases: 193
New cases: 172
New cases: 190
New cases: 135
New cases: 112
New cases: 89
New cases: 157
New cases: 178
New cases: 152
New cases: 258
12,816
689
South Carolina
New cases: 207
New cases: 238
New cases: 82
New cases: 201
New cases: 257
New cases: 257
New cases: 206
New cases: 119
New cases: 114
New cases: 126
New cases: 155
New cases: 254
New cases: 218
New cases: 159
New cases: 103
New cases: 135
New cases: 139
New cases: 122
New cases: 164
New cases: 225
New cases: 206
10,623
466
Kansas
New cases: 92
New cases: 74
New cases: 121
New cases: 58
New cases: 37
New cases: 284
New cases: 118
New cases: 154
New cases: 50
New cases: 350
New cases: 14
New cases: 53
New cases: 181
New cases: 187
New cases: 278
New cases: 81
New cases: 208
New cases: 122
New cases: 162
New cases: 335
New cases: 339
9,291
213
Delaware
New cases: 30
New cases: 101
New cases: 156
New cases: 280
New cases: 0
New cases: 143
New cases: 192
New cases: 157
New cases: 168
New cases: 199
New cases: 123
New cases: 174
New cases: 150
New cases: 271
New cases: 211
New cases: 176
New cases: 288
New cases: 0
New cases: 166
New cases: 172
New cases: 161
9,096
344
Kentucky
New cases: 126
New cases: 380
New cases: 0
New cases: 0
New cases: 145
New cases: 140
New cases: 119
New cases: 98
New cases: 134
New cases: 247
New cases: 0
New cases: 244
New cases: 219
New cases: 372
New cases: 0
New cases: 176
New cases: 237
New cases: 0
New cases: 152
New cases: 159
New cases: 195
9,077
400
Utah
New cases: 86
New cases: 99
New cases: 129
New cases: 132
New cases: 203
New cases: 183
New cases: 164
New cases: 192
New cases: 134
New cases: 146
New cases: 170
New cases: 155
New cases: 164
New cases: 129
New cases: 188
New cases: 70
New cases: 111
New cases: 148
New cases: 184
New cases: 195
New cases: 129
8,706
105
District of Columbia
New cases: 72
New cases: 109
New cases: 115
New cases: 144
New cases: 73
New cases: 105
New cases: 237
New cases: 117
New cases: 164
New cases: 147
New cases: 81
New cases: 171
New cases: 135
New cases: 152
New cases: 99
New cases: 96
New cases: 117
New cases: 170
New cases: 203
New cases: 245
New cases: 193
8,406
445
Nevada
New cases: 93
New cases: 101
New cases: 75
New cases: 355
New cases: 1
New cases: 125
New cases: 12
New cases: 292
New cases: 35
New cases: 112
New cases: 136
New cases: 80
New cases: 229
New cases: 28
New cases: 163
New cases: 161
New cases: 32
New cases: -51
New cases: 251
New cases: 65
New cases: 114
8,150
402
New Mexico
New cases: 122
New cases: 104
New cases: 83
New cases: 318
New cases: 0
New cases: 153
New cases: 155
New cases: 125
New cases: 96
New cases: 158
New cases: 91
New cases: 185
New cases: 159
New cases: 139
New cases: 152
New cases: 143
New cases: 206
New cases: 85
New cases: 105
New cases: 180
New cases: 202
7,252
329
Arkansas
New cases: 97
New cases: 151
New cases: 107
New cases: 147
New cases: 163
New cases: 154
New cases: 455
New cases: 80
New cases: 110
New cases: 54
New cases: 181
New cases: 115
New cases: 97
New cases: 130
New cases: 72
New cases: 121
New cases: 31
New cases: 265
New cases: 0
New cases: 44
New cases: 92
6,277
120
Oklahoma
New cases: 91
New cases: 48
New cases: 53
New cases: 77
New cases: 111
New cases: 169
New cases: 148
New cases: 43
New cases: 91
New cases: 88
New cases: 73
New cases: 150
New cases: 124
New cases: 105
New cases: 126
New cases: 119
New cases: 24
New cases: 99
New cases: 66
New cases: 94
New cases: 128
6,229
322
South Dakota
New cases: 57
New cases: 67
New cases: 23
New cases: 99
New cases: 108
New cases: 179
New cases: 0
New cases: 92
New cases: 58
New cases: 40
New cases: 28
New cases: 72
New cases: 95
New cases: 60
New cases: 69
New cases: 49
New cases: 97
New cases: 124
New cases: 248
New cases: 239
New cases: 126
4,710
54
New Hampshire
New cases: 55
New cases: 34
New cases: 48
New cases: 60
New cases: 75
New cases: 79
New cases: 67
New cases: 147
New cases: 69
New cases: 56
New cases: 40
New cases: 103
New cases: 71
New cases: 83
New cases: 60
New cases: 79
New cases: 89
New cases: 60
New cases: 64
New cases: 104
New cases: 102
4,286
223
Oregon
New cases: 71
New cases: 18
New cases: 22
New cases: 39
New cases: 24
New cases: 47
New cases: 16
New cases: 75
New cases: 39
New cases: 64
New cases: 11
New cases: 71
New cases: 62
New cases: 63
New cases: 58
New cases: 72
New cases: 58
New cases: 68
New cases: 92
New cases: 79
New cases: 73
4,038
148
Puerto Rico
New cases: 73
New cases: 64
New cases: 71
New cases: 89
New cases: 70
New cases: 117
New cases: 47
New cases: 61
New cases: 95
New cases: 64
New cases: 57
New cases: 47
New cases: 115
New cases: 98
New cases: 30
New cases: 43
New cases: 58
New cases: 25
New cases: 17
New cases: 125
New cases: 63
3,397
129
Idaho
New cases: 73
New cases: 0
New cases: 0
New cases: 31
New cases: 0
New cases: 89
New cases: 0
New cases: 51
New cases: 0
New cases: 36
New cases: 0
New cases: 68
New cases: 0
New cases: 58
New cases: 0
New cases: 33
New cases: 30
New cases: 25
New cases: 27
New cases: 0
New cases: 20
2,699
81
North Dakota
New cases: 17
New cases: -35
New cases: 39
New cases: 53
New cases: 48
New cases: 88
New cases: 134
New cases: 101
New cases: 63
New cases: 31
New cases: 52
New cases: 87
New cases: 49
New cases: 65
New cases: 76
New cases: 53
New cases: 27
New cases: 27
New cases: 39
New cases: 54
New cases: 48
2,439
56
Maine
New cases: 28
New cases: 35
New cases: 19
New cases: 42
New cases: 65
New cases: 71
New cases: 58
New cases: 78
New cases: 28
New cases: 26
New cases: 39
New cases: 45
New cases: 38
New cases: 50
New cases: 38
New cases: 15
New cases: 26
New cases: 28
New cases: 34
New cases: 44
New cases: 76
2,137
81
West Virginia
New cases: 125
New cases: 0
New cases: 15
New cases: 54
New cases: 0
New cases: 112
New cases: 26
New cases: 65
New cases: 0
New cases: 10
New cases: 22
New cases: 23
New cases: 20
New cases: 29
New cases: 20
New cases: 12
New cases: 6
New cases: 37
New cases: 0
New cases: 36
New cases: 45
1,899
74
Vermont
New cases: 4
New cases: 5
New cases: 6
New cases: 2
New cases: 2
New cases: 2
New cases: 6
New cases: 0
New cases: 4
New cases: 0
New cases: 6
New cases: 1
New cases: 1
New cases: 3
New cases: 2
New cases: 1
New cases: -1
New cases: 6
New cases: 2
New cases: 3
New cases: 8
971
54
Wyoming
New cases: 10
New cases: 7
New cases: 5
New cases: 25
New cases: 10
New cases: 2
New cases: 14
New cases: 11
New cases: 10
New cases: 12
New cases: 13
New cases: 25
New cases: 15
New cases: 13
New cases: 13
New cases: 6
New cases: 7
New cases: 9
New cases: 9
New cases: 9
New cases: 4
860
14
Hawaii
New cases: 1
New cases: 0
New cases: 0
New cases: 0
New cases: 1
New cases: -5
New cases: 4
New cases: 2
New cases: 1
New cases: 0
New cases: 1
New cases: 1
New cases: 1
New cases: -1
New cases: 3
New cases: 1
New cases: 2
New cases: 1
New cases: 2
New cases: 0
New cases: 3
644
17
Montana
New cases: 2
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 1
New cases: 7
New cases: 1
New cases: 2
New cases: 0
New cases: 2
New cases: 4
New cases: 0
New cases: 1
New cases: 2
New cases: 1
New cases: 0
New cases: 0
New cases: 2
New cases: 0
481
17
Alaska
New cases: 1
New cases: 2
New cases: 1
New cases: 0
New cases: 4
New cases: 2
New cases: 0
New cases: 1
New cases: 12
New cases: 0
New cases: 0
New cases: 0
New cases: 5
New cases: 0
New cases: 0
New cases: 4
New cases: 0
New cases: 1
New cases: 1
New cases: 3
New cases: 2
411
10
Guam
New cases: 3
New cases: 1
New cases: 0
New cases: 1
New cases: 0
New cases: 0
New cases: 11
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 2
New cases: 0
New cases: 0
New cases: 1
New cases: 0
New cases: 0
New cases: 0
New cases: 2
New cases: 0
170
5
Virgin Islands
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 1
New cases: 0
New cases: 2
New cases: 0
69
6
Northern Marianas
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 1
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 2
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 3
New cases: 0
New cases: 1
New cases: 0
New cases: 0
22
2
American Samoa
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
New cases: 0
0
0